# ROSE - The **R**educed-**O**rder **S**cattering **E**mulator

ROSE makes it easy to build and train a scattering emulator. The project 

For any bug reports or feature requests, please make use of the Github issues tab on the repository. We also welcome all pull requests for software, documentation, and user-contributed tutorials! 

## Installation

To install, run the following 

`pip install nuclear-rose`

## Usage

The primary class is `ReducedBasisEmulator`. To create an instance, minimally, an instance of the `Interaction` class, a set of training points, the energy, and angular momentum need to be specified. 

For a full set of examples walking through emulation and calibration, check the [tutorials](docs/tutorials/) directory.

